==> cb-helpers-0.4.0.tgz: package/index.js <==
﻿"use strict";
// ReSharper disable UnusedLocals
// ReSharper disable AssignedValueIsNeverUsed


const util = require("util");
const Readline = require('readline');
const chalk = require("chalk");
const _ = require("lodash");
const Q = require('q');

const readline = Readline.createInterface(process.stdin, process.stdout);

const toListItem = (index, item) => `[${index + 1}] ${typeof item === "object" ? util.inspect(item) : item}`;

const questionAsync = exports.questionAsync =
  text => {
    const deferred = Q.defer();
    readline.question(text, deferred.resolve);
    return deferred.promise;
  };

const yesNoAsync = exports.yesNoAsync =
  question => questionAsync(`${question} (Y/n) `).then(answer => answer.toLowerCase() !== 'n');

const noYesAsync = exports.noYesAsync =
  question => questionAsync(`${question} (N/y) `).then(answer => answer.toLowerCase() === 'y');

const chooseFromAsync = exports.chooseFromAsync =
  (items, question, map = null) => {
    let listItems;
    switch (typeof map) {
      case 'function':
        listItems = Array.prototype.map.call(items, (item, index) => toListItem(index, map(item)));
        break;
      case 'string':
      case 'number':
        listItems = Array.prototype.map.call(items, (item, index) => toListItem(index, item[map]));
        break;
      default:
        listItems = Array.prototype.map.call(items, (item, index) => toListItem(index, item));
        break;
    }

    const text = `${listItems.join('\n')}\n${question} Choose item #: `;
    return questionAsync(text)
      .then(answer => {
        const index = parseInt(answer, 10) - 1;
        return [index, items[index]];
      });
  };

const br = exports.br = (n = 1) => console.log(_.repeat("\r\n", n - 1));
const line = exports.line = (content = "<LINE>", charCount = 80) => {
  const inlinePad = Math.min(content.length + 10, charCount);
  const inline = chalk.magenta(_.pad(content, inlinePad));
  console.log(chalk.gray(_.pad(inline, charCount + 10, "=")));
};
const titleLine = exports.titleLine = (title = "<TITLE>", charCount = 80) => {
  const border = chalk.gray(_.repeat("=", charCount));
  console.log(border);
  line(title, charCount);
  console.log(border);
};
const titleStart = exports.titleStart = (title, charCount) => {
  br(2);
  titleLine(title, charCount);
};
const titleEnd = exports.titleEnd = (title, charCount) => {
  titleLine(title, charCount);
  br(2);
};
const normal = exports.normal = chalk.reset;
const info = exports.info = chalk.bold.cyan;
const danger = exports.danger = chalk.bold.red;
const succeed = exports.succeed = chalk.bold.green;
const warning = exports.warning = chalk.bold.yellow;
const symbol = exports.symbol = chalk.bold.magenta;

exports.log = (...tokens) => log(normal, ...tokens);
const logInfo = exports.logInfo = (...tokens) => log(info, ...tokens);
const logDanger = exports.logDanger = (...tokens) => log(danger, ...tokens);
const logSucceed = exports.logSucceed = (...tokens) => log(succeed, ...tokens);
const logWarning = exports.logWarning = (...tokens) => log(warning, ...tokens);
const logGroup = exports.logGroup = (title, ...group) => {
  logInfo(title);
  group.forEach(exp => log(normal, '\t', exp));
};
const logEvalInfo = exports.logEvalInfo = (...tokens) => logEval(info, ...tokens);
const logEvalDanger = exports.logEvalDanger = (...tokens) => logEval(danger, ...tokens);
const logEvalSucceed = exports.logEvalSucceed = (...tokens) => logEval(succeed, ...tokens);
const logEvalWarning = exports.logEvalWarning = (...tokens) => logEval(warning, ...tokens);

const logInfoTitle = exports.logInfoTitle = (title, ...tokens) => logTitle(info, title, ...tokens);
const logDangerTitle = exports.logDangerTitle = (title, ...tokens) => logTitle(danger, title, ...tokens);
const logSucceedTitle = exports.logSucceedTitle = (title, ...tokens) => logTitle(succeed, title, ...tokens);
const logWarningTitle = exports.logWarningTitle = (title, ...tokens) => logTitle(warning, title, ...tokens);

const logEvalInfoTitle = exports.logEvalInfoTitle = (title, ...tokens) => logEvalTitle(info, title, ...tokens);
const logEvalDangerTitle = exports.logEvalDangerTitle = (title, ...tokens) => logEvalTitle(danger, title, ...tokens);
const logEvalSucceedTitle = exports.logEvalSucceedTitle = (title, ...tokens) => logEvalTitle(succeed, title, ...tokens);
const logEvalWarningTitle = exports.logEvalWarningTitle = (title, ...tokens) => logEvalTitle(warning, title, ...tokens);

const createInfoTitleLogger = exports.createInfoTitleLogger = title => logInfoTitle.bind(null, title);
const createDangerTitleLogger = exports.createDangerTitleLogger = title => logDangerTitle.bind(null, title);
const createSucceedTitleLogger = exports.createSucceedTitleLogger = title => logSucceedTitle.bind(null, title);
const createWarningTitleLogger = exports.createWarningTitleLogger = title => logWarningTitle.bind(null, title);

const logPromise = exports.logPromise = (promise, promiseName) => {
  const start = Date.now();
  promise
    .then((...res) => logSucceedTitle(`${promiseName} result:`, ...res, `in ${Date.now() - start}ms`))
    .catch(err => logDangerTitle(`${promiseName} error:`, err.message, `in ${Date.now() - start}ms`));
};

function toString(value) {
  return typeof value === "object"
           ? util.inspect(value, true, null)
           : typeof value === "undefined" ? "undefined" : value.toString();
}

function getFuncContent(f) {
  return f.toString().match(/=>\s*(.*)/)[1];
}

function getFuncResult(f) {
  try {
    return succeed(toString(f()));
  } catch (e) {
    return danger(e.message);
  }
}

function getEvalText(...tokens) {
  return tokens.map(t => `${t} ${symbol('=>')} ${getFuncResult(eval.bind(null, t))}`);
}

function getTokenTexts(...tokens) {
  return tokens.map(t => {
    return typeof t === "function"
             ? `${getFuncContent(t)} ${symbol('=>')} ${getFuncResult(t)}`
             : toString(t);
  });
}

function logTexts(style, ...texts) {
  console.log(style(...texts));
}

function log(style, ...tokens) {
  const texts = getTokenTexts(...tokens);
  logTexts(style, ...texts);
}

function logEval(style, ...tokens) {
  const texts = getEvalText(...tokens);
  log(style, ...texts);
}

function logTitle(style, title, ...tokens) {
  const texts = getTokenTexts(...tokens);
  console.log(style(title), ...texts);
}

function logEvalTitle(style, title, ...tokens) {
  const texts = getEvalText(...tokens);
  logTitle(style, title, ...texts);
}

==> cb-helpers-0.5.0.tgz: package/index.js <==
﻿"use strict";
// ReSharper disable UnusedLocals
// ReSharper disable AssignedValueIsNeverUsed


const util = require("util");
const Readline = require('readline');
const chalk = require("chalk");
const _ = require("lodash");
const Q = require('q');

const readline = Readline.createInterface(process.stdin, process.stdout);

const toListItem = (index, item) => `[${index + 1}] ${typeof item === "object" ? util.inspect(item) : item}`;

const questionAsync = exports.questionAsync =
  text => {
    const deferred = Q.defer();
    readline.question(text, deferred.resolve);
    return deferred.promise;
  };

const yesNoAsync = exports.yesNoAsync =
  question => questionAsync(`${question} (Y/n) `).then(answer => answer.toLowerCase() !== 'n');

const noYesAsync = exports.noYesAsync =
  question => questionAsync(`${question} (N/y) `).then(answer => answer.toLowerCase() === 'y');

const chooseFromAsync = exports.chooseFromAsync =
  (items, question, map = null) => {
    let listItems;
    switch (typeof map) {
      case 'function':
        listItems = Array.prototype.map.call(items, (item, index) => toListItem(index, map(item)));
        break;
      case 'string':
      case 'number':
        listItems = Array.prototype.map.call(items, (item, index) => toListItem(index, item[map]));
        break;
      default:
        listItems = Array.prototype.map.call(items, (item, index) => toListItem(index, item));
        break;
    }

    const text = `${listItems.join('\n')}\n${question} Choose item #: `;
    return questionAsync(text)
      .then(answer => {
        const index = parseInt(answer, 10) - 1;
        return [index, items[index]];
      });
  };

const br = exports.br = (n = 1) => console.log(_.repeat("\r\n", n - 1));
const line = exports.line = (content = "<LINE>", charCount = 80) => {
  const inlinePad = Math.min(content.length + 10, charCount);
  const inline = chalk.magenta(_.pad(content, inlinePad));
  console.log(chalk.gray(_.pad(inline, charCount + 10, "=")));
};
const titleLine = exports.titleLine = (title = "<TITLE>", charCount = 80) => {
  const border = chalk.gray(_.repeat("=", charCount));
  console.log(border);
  line(title, charCount);
  console.log(border);
};
const titleStart = exports.titleStart = (title, charCount) => {
  br(2);
  titleLine(title, charCount);
};
const titleEnd = exports.titleEnd = (title, charCount) => {
  titleLine(title, charCount);
  br(2);
};
const normal = exports.normal = chalk.reset;
const info = exports.info = chalk.bold.cyan;
const danger = exports.danger = chalk.bold.red;
const succeed = exports.succeed = chalk.bold.green;
const warning = exports.warning = chalk.bold.yellow;
const symbol = exports.symbol = chalk.bold.magenta;

const logNormal = exports.log = exports.logNormal = (...tokens) => log(normal, ...tokens);
const logInfo = exports.logInfo = (...tokens) => log(info, ...tokens);
const logDanger = exports.logDanger = (...tokens) => log(danger, ...tokens);
const logSucceed = exports.logSucceed = (...tokens) => log(succeed, ...tokens);
const logWarning = exports.logWarning = (...tokens) => log(warning, ...tokens);
const logGroup = exports.logGroup = (...group) => logNormal(groupToTokens(group));

const logEvalInfo = exports.logEvalInfo = (...tokens) => logEval(info, ...tokens);
const logEvalDanger = exports.logEvalDanger = (...tokens) => logEval(danger, ...tokens);
const logEvalSucceed = exports.logEvalSucceed = (...tokens) => logEval(succeed, ...tokens);
const logEvalWarning = exports.logEvalWarning = (...tokens) => logEval(warning, ...tokens);

const logInfoTitle = exports.logInfoTitle = (title, ...tokens) => logTitle(info, title, ...tokens);
const logDangerTitle = exports.logDangerTitle = (title, ...tokens) => logTitle(danger, title, ...tokens);
const logSucceedTitle = exports.logSucceedTitle = (title, ...tokens) => logTitle(succeed, title, ...tokens);
const logWarningTitle = exports.logWarningTitle = (title, ...tokens) => logTitle(warning, title, ...tokens);
const logGroupTitle = exports.logGroupTitle = (title, ...group) => logInfoTitle(title, groupToTokens(group));

const logEvalInfoTitle = exports.logEvalInfoTitle = (title, ...tokens) => logEvalTitle(info, title, ...tokens);
const logEvalDangerTitle = exports.logEvalDangerTitle = (title, ...tokens) => logEvalTitle(danger, title, ...tokens);
const logEvalSucceedTitle = exports.logEvalSucceedTitle = (title, ...tokens) => logEvalTitle(succeed, title, ...tokens);
const logEvalWarningTitle = exports.logEvalWarningTitle = (title, ...tokens) => logEvalTitle(warning, title, ...tokens);

const createInfoTitleLogger = exports.createInfoTitleLogger = title => logInfoTitle.bind(null, title);
const createDangerTitleLogger = exports.createDangerTitleLogger = title => logDangerTitle.bind(null, title);
const createSucceedTitleLogger = exports.createSucceedTitleLogger = title => logSucceedTitle.bind(null, title);
const createWarningTitleLogger = exports.createWarningTitleLogger = title => logWarningTitle.bind(null, title);

const logPromise = exports.logPromise = (promise, promiseName) => {
  const start = Date.now();
  promise
    .then((...res) => logSucceedTitle(`${promiseName} result:`, ...res, `in ${Date.now() - start}ms`))
    .catch(err => logDangerTitle(`${promiseName} error:`, err.message, `in ${Date.now() - start}ms`));
};

function groupToTokens(group) {
  return group.map(exp => ['\t', exp]);
}

function toString(value) {
  return typeof value === "object"
           ? util.inspect(value, true, null)
           : typeof value === "undefined" ? "undefined" : value.toString();
}

function getFuncContent(f) {
  return f.toString().match(/=>\s*(.*)/)[1];
}

function getFuncResult(f) {
  try {
    return succeed(toString(f()));
  } catch (e) {
    return danger(e.message);
  }
}

function getEvalText(...tokens) {
  return tokens.map(t => `${t} ${symbol('=>')} ${getFuncResult(eval.bind(null, t))}`);
}

function getTokenTexts(...tokens) {
  return tokens.map(t => {
    return typeof t === "function"
             ? `${getFuncContent(t)} ${symbol('=>')} ${getFuncResult(t)}`
             : toString(t);
  });
}

function logTexts(style, ...texts) {
  console.log(style(...texts));
}

function log(style, ...tokens) {
  const texts = getTokenTexts(...tokens);
  logTexts(style, ...texts);
}

function logEval(style, ...tokens) {
  const texts = getEvalText(...tokens);
  log(style, ...texts);
}

function logTitle(style, title, ...tokens) {
  const texts = getTokenTexts(...tokens);
  console.log(style(title), ...texts);
}

function logEvalTitle(style, title, ...tokens) {
  const texts = getEvalText(...tokens);
  logTitle(style, title, ...texts);
}
